## Summary

<!-- What does this PR do? Keep it to 1-3 sentences. -->

## Changes

<!-- Bullet list of key changes -->

## Test Plan

<!-- How was this tested? -->

- [ ] Tests pass locally
- [ ] Manually verified

## Checklist

- [ ] Code follows project conventions (see CLAUDE.md)
- [ ] No unrelated changes
- [ ] Tests added/updated for new functionality
- [ ] Documentation updated if needed
